/*

	MultipleConfigReader

	Author:	Vendicator
	
	Description:
	Class that handles the reading of *lines from .rc files
	and stores them for processing.

	Requires:

	Changelog:
	[2003-06-12 - Vendicator]
	- Using SafeString class

	[2003-03-22 - Vendicator]
	- First work?
	
*/

#include "lsapi_location.h"
#include "apis.h"
#include "MultipleConfigReader.h"

MultipleConfigReader::MultipleConfigReader(LPCTSTR configname)
{
	configName.assign(configname);

	ReadConfigs();

	ResetConfigIterator();
}

MultipleConfigReader::MultipleConfigReader(LPCTSTR prefix, LPCTSTR config)
{
	configName.assign(prefix);
	configName.append(config);

	ReadConfigs();

	ResetConfigIterator();
}

MultipleConfigReader::~MultipleConfigReader()
{
	PurgeConfigs();
}

void MultipleConfigReader::PurgeConfigs()
{
	// remove all configs entered
	for(Configs::iterator i = ConfigLines.begin(); i != ConfigLines.end(); i++)
	{
		delete (*i);
	}
	ConfigLines.clear();
}

void MultipleConfigReader::ResetConfigIterator()
{
	iter = ConfigLines.begin();
}

void MultipleConfigReader::ReReadConfigs()
{
	PurgeConfigs();

	ReadConfigs();

	ResetConfigIterator();
}

bool MultipleConfigReader::HasMoreConfigs()
{
	return (iter != ConfigLines.end());
}

// gets the configs that have been read, or NULL for end
LPCTSTR MultipleConfigReader::GetNextConfig()
{
	LPCTSTR configline = NULL;
	if (iter != ConfigLines.end())
	{
		// return this config
		configline = (*iter)->c_str();
		// get ready to return the next one on next invocation
		iter++;
	}
	return configline;
}

void MultipleConfigReader::ReadConfigs()
{
	FILE *steprc;
	TCHAR linebuffer[4096];
	SafeString* config;

	steprc = LCOpen(NULL);
	if (steprc)
	{
		while ( LCReadNextConfig(steprc, configName.c_str(), linebuffer, sizeof(linebuffer)-1) )
		{
			config = new SafeString(linebuffer);

			// insert the lines found
			ConfigLines.push_back(config);
		}
		LCClose(steprc);
	}
	else
	{
		_LSLog(LOG_ERROR, LogName, "can't open .rc file for reading");
	}
}
